@@ -220,63 +220,21 @@ class XAAutomatorDocumentList(XABase.XAList):
         super().__init__(properties, XAAutomatorDocument, filter)
 
     def id(self) -> list[int]:
-        """Retrieves the ID of each document in the list.
-
-        :return: The list of document IDs.
-        :rtype: list[int]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("id"))
+        return list(self.xa_elem.arrayByApplyingSelector_("id") or [])
 
     def title(self) -> list[str]:
-        """Retrieves the title of each document in the list.
-
-        :return: The list of document titles.
-        :rtype: list[str]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("title"))
+        return list(self.xa_elem.arrayByApplyingSelector_("title") or [])
 
     def index(self) -> list[int]:
-        """Retrieves the index of each document in the list.
-
-        :return: The list of document indexes.
-        :rtype: list[int]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("index"))
+        return list(self.xa_elem.arrayByApplyingSelector_("index") or [])
 
     def by_id(self, id: int) -> Union['XAAutomatorDocument', None]:
-        """Retrieves the document whose ID matches the given ID, if one exists.
-
-        :return: The desired document, if it is found
-        :rtype: Union[XAAutomatorDocument, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("id", id)
 
     def by_title(self, title: str) -> Union['XAAutomatorDocument', None]:
-        """Retrieves the first document whose title matches the given title, if one exists.
-
-        :return: The desired document, if it is found
-        :rtype: Union[XAAutomatorDocument, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("title", title)
 
     def by_index(self, index: int) -> Union['XAAutomatorDocument', None]:
-        """Retrieves the document whose index matches the given index, if one exists.
-
-        :return: The desired document, if it is found
-        :rtype: Union[XAAutomatorDocument, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("index", index)
 
     def __repr__(self):
@@ -337,445 +295,137 @@ class XAAutomatorActionList(XABase.XAList):
         super().__init__(properties, XAAutomatorAction, filter)
 
     def bundle_id(self) -> list[str]:
-        """Retrieves the bundle identifier of each action in the list.
-
-        :return: The list of bundle identifiers.
-        :rtype: list[str]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("bundleId"))
+        return list(self.xa_elem.arrayByApplyingSelector_("bundleId") or [])
 
     def category(self) -> list[list[str]]:
-        """Retrieves the category/categories of each action in the list.
-
-        :return: The list of categories.
-        :rtype: list[list[str]]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("category"))
+        return list(self.xa_elem.arrayByApplyingSelector_("category") or [])
 
     def comment(self) -> list[str]:
-        """Retrieves the comments of each action in the list.
-
-        :return: The list of comments.
-        :rtype: list[str]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("comment"))
+        return list(self.xa_elem.arrayByApplyingSelector_("comment") or [])
 
     def enabled(self) -> list[bool]:
-        """Retrieves the enabled status of each action in the list.
-
-        :return: The list of enabled status booleans.
-        :rtype: list[bool]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("enabled"))
+        return list(self.xa_elem.arrayByApplyingSelector_("enabled") or [])
 
     def execution_error_message(self) -> list[str]:
-        """Retrieves the execution error message of each action in the list.
-
-        :return: The list of error messages.
-        :rtype: list[str]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("executionErrorMessage"))
+        return list(self.xa_elem.arrayByApplyingSelector_("executionErrorMessage") or [])
 
     def execution_error_number(self) -> list[int]:
-        """Retrieves the execution error number of each action in the list.
-
-        :return: The list of error numbers.
-        :rtype: list[int]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("executionErrorNumber"))
+        return list(self.xa_elem.arrayByApplyingSelector_("executionErrorNumber") or [])
 
     def execution_result(self) -> list[Any]:
-        """Retrieves the result value of each action in the list.
-
-        :return: The list of results.
-        :rtype: list[Any]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("executionResult"))
+        return list(self.xa_elem.arrayByApplyingSelector_("executionResult") or [])
 
     def icon_name(self) -> list[str]:
-        """Retrieves the icon name of each action in the list.
-
-        :return: The list of icon names.
-        :rtype: list[str]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("iconName"))
+        return list(self.xa_elem.arrayByApplyingSelector_("iconName") or [])
 
     def ignores_input(self) -> list[bool]:
-        """Retrieves the ignore input status of each action in the list.
-
-        :return: The list of ignore input status booleans.
-        :rtype: list[bool]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("ignoresInput"))
+        return list(self.xa_elem.arrayByApplyingSelector_("ignoresInput") or [])
 
     def index(self) -> list[int]:
-        """Retrieves the index of each action in the list.
-
-        :return: The list of action indices.
-        :rtype: list[int]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("index"))
+        return list(self.xa_elem.arrayByApplyingSelector_("index") or [])
 
     def input_types(self) -> list[list[str]]:
-        """Retrieves the input types of each action in the list.
-
-        :return: The list of input types.
-        :rtype: list[list[str]]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("inputTypes"))
+        return list(self.xa_elem.arrayByApplyingSelector_("inputTypes") or [])
 
     def keywords(self) -> list[list[str]]:
-        """Retrieves the keywords of each action in the list.
-
-        :return: The list of keywords.
-        :rtype: list[list[str]]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("keywords"))
+        return list(self.xa_elem.arrayByApplyingSelector_("keywords") or [])
 
     def name(self) -> list[str]:
-        """Retrieves the name of each action in the list.
-
-        :return: The list of names.
-        :rtype: list[str]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("name"))
+        return list(self.xa_elem.arrayByApplyingSelector_("name") or [])
 
     def output_types(self) -> list[list[str]]:
-        """Retrieves the output types of each action in the list.
-
-        :return: The list of output types.
-        :rtype: list[list[str]]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("outputTypes"))
+        return list(self.xa_elem.arrayByApplyingSelector_("outputTypes") or [])
 
     def parent_workflow(self) -> 'XAAutomatorWorkflowList':
-        """Retrieves the parent workflow of each action in the list.
-
-        :return: The list of parent workflows.
-        :rtype: XAAutomatorWorkflowList
-
-        .. versionadded:: 0.0.4
-        """
-        ls = self.xa_elem.arrayByApplyingSelector_("parentWorkflow")
+        ls = self.xa_elem.arrayByApplyingSelector_("parentWorkflow") or []
         return self._new_element(ls, XAAutomatorWorkflowList)
 
     def path(self) -> list[str]:
-        """Retrieves the file path of each action in the list.
-
-        :return: The list of paths.
-        :rtype: list[str]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("path"))
+        return list(self.xa_elem.arrayByApplyingSelector_("path") or [])
 
     def show_action_when_run(self) -> list[bool]:
-        """Retrieves the status of the show action when run setting of each action in the list.
-
-        :return: The list of boolean statuses.
-        :rtype: list[bool]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("showActionWhenRun"))
+        return list(self.xa_elem.arrayByApplyingSelector_("showActionWhenRun") or [])
 
     def target_application(self) -> list[list[str]]:
-        """Retrieves the target application name of each action in the list.
-
-        :return: The list of target application names.
-        :rtype: list[list[str]]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("targetApplication"))
+        return list(self.xa_elem.arrayByApplyingSelector_("targetApplication") or [])
 
     def version(self) -> list[str]:
-        """Retrieves the version of each action in the list.
-
-        :return: The list of versions.
-        :rtype: list[str]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("version"))
+        return list(self.xa_elem.arrayByApplyingSelector_("version") or [])
 
     def warning_action(self) -> list[str]:
-        """Retrieves the warning action of each action in the list.
-
-        :return: The list of warning actions.
-        :rtype: list[str]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("warningAction"))
+        return list(self.xa_elem.arrayByApplyingSelector_("warningAction") or [])
 
     def warning_level(self) -> list[XAAutomatorApplication.WarningLevel]:
-        """Retrieves the warning level of each action in the list.
-
-        :return: The list of warning levels.
-        :rtype: list[XAAutomatorApplication.WarningLevel]
-
-        .. versionadded:: 0.0.4
-        """
-        ls = self.xa_elem.arrayByApplyingSelector_("warningLevel")
+        ls = self.xa_elem.arrayByApplyingSelector_("warningLevel") or []
         return [XAAutomatorApplication.WarningLevel(x) for x in ls]
 
     def warning_message(self) -> list[str]:
-        """Retrieves the warning message of each action in the list.
-
-        :return: The list of warning messages.
-        :rtype: list[str]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("warningMessage"))
+        return list(self.xa_elem.arrayByApplyingSelector_("warningMessage") or [])
 
     def by_bundle_id(self, bundle_id: str) -> Union['XAAutomatorAction', None]:
-        """Retrieves the first action whose bundle identifier matches the given identifier, if one exists.
-
-        :return: The desired action, if it is found
-        :rtype: Union[XAAutomatorAction, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("bundleId", bundle_id)
 
     def by_category(self, category: list[str]) -> Union['XAAutomatorAction', None]:
-        """Retrieves the first action whose category matches the given category, if one exists.
-
-        :return: The desired action, if it is found
-        :rtype: Union[XAAutomatorAction, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("category", category)
 
     def by_comment(self, comment: str) -> Union['XAAutomatorAction', None]:
-        """Retrieves the first action whose comment matches the given comment, if one exists.
-
-        :return: The desired action, if it is found
-        :rtype: Union[XAAutomatorAction, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("comment", comment)
 
     def by_enabled(self, enabled: bool) -> Union['XAAutomatorAction', None]:
-        """Retrieves the first action whose enabled status matches the given boolean value, if one exists.
-
-        :return: The desired action, if it is found
-        :rtype: Union[XAAutomatorAction, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("enabled", enabled)
 
     def by_execution_error_message(self, execution_error_message: str) -> Union['XAAutomatorAction', None]:
-        """Retrieves the first action whose error message matches the given message, if one exists.
-
-        :return: The desired action, if it is found
-        :rtype: Union[XAAutomatorAction, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("executionErrorMessage", execution_error_message)
 
     def by_execution_error_number(self, execution_error_number: int) -> Union['XAAutomatorAction', None]:
-        """Retrieves the first action whose error number matches the given error number, if one exists.
-
-        :return: The desired action, if it is found
-        :rtype: Union[XAAutomatorAction, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("executionErrorNumber", execution_error_number)
 
     def by_execution_result(self, execution_result: Any) -> Union['XAAutomatorAction', None]:
-        """Retrieves the first action whose execution result matches the given value, if one exists.
-
-        :return: The desired action, if it is found
-        :rtype: Union[XAAutomatorAction, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("executionResult", execution_result)
 
     def by_icon_name(self, icon_name: str) -> Union['XAAutomatorAction', None]:
-        """Retrieves the first action whose icon name matches the given name, if one exists.
-
-        :return: The desired action, if it is found
-        :rtype: Union[XAAutomatorAction, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("iconName", icon_name)
 
     def by_id(self, id: str) -> Union['XAAutomatorAction', None]:
-        """Retrieves the action whose ID matches the given ID, if one exists.
-
-        :return: The desired action, if it is found
-        :rtype: Union[XAAutomatorAction, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("id", id)
 
     def by_ignores_input(self, ignores_input: bool) -> Union['XAAutomatorAction', None]:
-        """Retrieves the first action whose ignore input status matches the given boolean value, if one exists.
-
-        :return: The desired action, if it is found
-        :rtype: Union[XAAutomatorAction, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("ignoresInput", ignores_input)
 
     def by_input_types(self, input_types: list[str]) -> Union['XAAutomatorAction', None]:
-        """Retrieves the first action whose input types match the given input types, if one exists.
-
-        :return: The desired action, if it is found
-        :rtype: Union[XAAutomatorAction, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("inputTypes", input_types)
 
     def by_keywords(self, keywords: list[str]) -> Union['XAAutomatorAction', None]:
-        """Retrieves the first action whose keywords match the given keywords, if one exists.
-
-        :return: The desired action, if it is found
-        :rtype: Union[XAAutomatorAction, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("keywords", keywords)
 
     def by_name(self, name: str) -> Union['XAAutomatorAction', None]:
-        """Retrieves the first action whose name matches the given name, if one exists.
-
-        :return: The desired action, if it is found
-        :rtype: Union[XAAutomatorAction, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("name", name)
 
     def by_output_types(self, output_types: list[str]) -> Union['XAAutomatorAction', None]:
-        """Retrieves the first action whose output types match the given output types, if one exists.
-
-        :return: The desired action, if it is found
-        :rtype: Union[XAAutomatorAction, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("outputTypes", output_types)
 
     def by_parent_workflow(self, parent_workflow: 'XAAutomatorWorkflow') -> Union['XAAutomatorAction', None]:
-        """Retrieves the first action whose parent workflow matches the given workflow, if one exists.
-
-        :return: The desired action, if it is found
-        :rtype: Union[XAAutomatorAction, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("parentWorkflow", parent_workflow.xa_elem)
 
     def by_path(self, path: str) -> Union['XAAutomatorAction', None]:
-        """Retrieves the first action whose path matches the given path, if one exists.
-
-        :return: The desired action, if it is found
-        :rtype: Union[XAAutomatorAction, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("path", path)
 
     def by_show_action_when_run(self, show_action_when_run: bool) -> Union['XAAutomatorAction', None]:
-        """Retrieves the first action whose show action when run status matches the given boolean value, if one exists.
-
-        :return: The desired action, if it is found
-        :rtype: Union[XAAutomatorAction, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("show_action_when_run", show_action_when_run)
 
     def by_target_application(self, target_application: list[str]) -> Union['XAAutomatorAction', None]:
-        """Retrieves the first action whose target application matches the given application name, if one exists.
-
-        :return: The desired action, if it is found
-        :rtype: Union[XAAutomatorAction, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("targetApplication", target_application)
 
     def by_version(self, version: str) -> Union['XAAutomatorAction', None]:
-        """Retrieves the first action whose version matches the given version, if one exists.
-
-        :return: The desired action, if it is found
-        :rtype: Union[XAAutomatorAction, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("version", version)
 
     def by_warning_action(self, warning_action: str) -> Union['XAAutomatorAction', None]:
-        """Retrieves the first action whose warning action matches the given action, if one exists.
-
-        :return: The desired action, if it is found
-        :rtype: Union[XAAutomatorAction, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("warningAction", warning_action)
 
     def by_warning_level(self, warning_level: XAAutomatorApplication.WarningLevel) -> Union['XAAutomatorAction', None]:
-        """Retrieves the first action whose warning level matches the given warning level, if one exists.
-
-        :return: The desired action, if it is found
-        :rtype: Union[XAAutomatorAction, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("warningLevel", warning_level.value)
 
     def by_warning_message(self, warning_message: str) -> Union['XAAutomatorAction', None]:
-        """Retrieves the first action whose warning message matches the given message, if one exists.
-
-        :return: The desired action, if it is found
-        :rtype: Union[XAAutomatorAction, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("warningMessage", warning_message)
 
     def __repr__(self):
@@ -990,83 +640,27 @@ class XAAutomatorRequiredResourceList(XABase.XAList):
         super().__init__(properties, XAAutomatorRequiredResource, filter)
 
     def kind(self) -> list[str]:
-        """Retrieves the resource type of each resource in the list.
-
-        :return: The list of resource types.
-        :rtype: list[str]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("kind"))
+        return list(self.xa_elem.arrayByApplyingSelector_("kind") or [])
 
     def name(self) -> list[str]:
-        """Retrieves the name of each resource in the list.
-
-        :return: The list of resource names.
-        :rtype: list[str]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("name"))
+        return list(self.xa_elem.arrayByApplyingSelector_("name") or [])
 
     def resource(self) -> list[str]:
-        """Retrieves the specification of each resource in the list.
-
-        :return: The list of resource specifications.
-        :rtype: list[str]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("resource"))
+        return list(self.xa_elem.arrayByApplyingSelector_("resource") or [])
 
     def version(self) -> list[int]:
-        """Retrieves the version of each resource in the list.
-
-        :return: The list of resource versions.
-        :rtype: list[int]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("version"))
+        return list(self.xa_elem.arrayByApplyingSelector_("version") or [])
 
     def by_kind(self, kind: str) -> Union['XAAutomatorRequiredResource', None]:
-        """Retrieves the first resource whose kind matches the given kind, if one exists.
-
-        :return: The desired resource, if it is found
-        :rtype: Union[XAAutomatorRequiredResource, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("kind", kind)
 
     def by_name(self, name: str) -> Union['XAAutomatorRequiredResource', None]:
-        """Retrieves the first resource whose name matches the given name, if one exists.
-
-        :return: The desired resource, if it is found
-        :rtype: Union[XAAutomatorRequiredResource, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("name", name)
 
     def by_resource(self, resource: str) -> Union['XAAutomatorRequiredResource', None]:
-        """Retrieves the first resource whose specification matches the given specification, if one exists.
-
-        :return: The desired resource, if it is found
-        :rtype: Union[XAAutomatorRequiredResource, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("resource", resource)
 
     def by_version(self, version: int) -> Union['XAAutomatorRequiredResource', None]:
-        """Retrieves the first resource whose version matches the given version, if one exists.
-
-        :return: The desired resource, if it is found
-        :rtype: Union[XAAutomatorRequiredResource, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("version", version)
 
     def __repr__(self):
@@ -1123,65 +717,23 @@ class XAAutomatorSettingList(XABase.XAList):
         super().__init__(properties, XAAutomatorSetting, filter)
 
     def default_value(self) -> list[Any]:
-        """Retrieves the default value of each setting in the list.
-
-        :return: The list of default values.
-        :rtype: list[Any]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("defaultValue"))
+        return list(self.xa_elem.arrayByApplyingSelector_("defaultValue") or [])
 
     def name(self) -> list[str]:
-        """Retrieves the name of each setting in the list.
-
-        :return: The list of setting names.
-        :rtype: list[str]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("name"))
+        return list(self.xa_elem.arrayByApplyingSelector_("name") or [])
 
     def value(self) -> list[Any]:
-        """Retrieves the current value of each setting in the list.
-
-        :return: The list of current values.
-        :rtype: list[Any]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("value"))
+        return list(self.xa_elem.arrayByApplyingSelector_("value") or [])
 
     def by_default_value(self, default_value: Any) -> Union['XAAutomatorSetting', None]:
-        """Retrieves the first setting whose default value matches the given value, if one exists.
-
-        :return: The desired setting, if it is found
-        :rtype: Union[XAAutomatorSetting, None]
-        
-        .. versionadded:: 0.0.4
-        """
         if isinstance(default_value, XABase.XAObject):
             default_value = default_value.xa_elem
         return self.by_property("defaultValue", default_value)
 
     def by_name(self, name: str) -> Union['XAAutomatorSetting', None]:
-        """Retrieves the first setting whose name matches the given name, if one exists.
-
-        :return: The desired setting, if it is found
-        :rtype: Union[XAAutomatorSetting, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("name", name)
 
     def by_value(self, value: Any) -> Union['XAAutomatorSetting', None]:
-        """Retrieves the first setting whose current value matches the given value, if one exists.
-
-        :return: The desired setting, if it is found
-        :rtype: Union[XAAutomatorSetting, None]
-        
-        .. versionadded:: 0.0.4
-        """
         if isinstance(value, XABase.XAObject):
             value = value.xa_elem
         return self.by_property("value", value)
@@ -1238,63 +790,21 @@ class XAAutomatorVariableList(XABase.XAList):
         super().__init__(properties, XAAutomatorVariable, filter)
 
     def name(self) -> list[str]:
-        """Retrieves the name of each variable in the list.
-
-        :return: The list of variable names.
-        :rtype: list[Any]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("name"))
+        return list(self.xa_elem.arrayByApplyingSelector_("name") or [])
 
     def settable(self) -> list[bool]:
-        """Retrieves the value of the settable attribute of each variable in the list.
-
-        :return: The list of settable status booleans.
-        :rtype: list[bool]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("settable"))
+        return list(self.xa_elem.arrayByApplyingSelector_("settable") or [])
 
     def value(self) -> list[Any]:
-        """Retrieves the current value of each variable in the list.
-
-        :return: The list of current values.
-        :rtype: list[Any]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("value"))
+        return list(self.xa_elem.arrayByApplyingSelector_("value") or [])
 
     def by_name(self, name: str) -> Union['XAAutomatorVariable', None]:
-        """Retrieves the first variable whose name matches the given name, if one exists.
-
-        :return: The desired variable, if it is found
-        :rtype: Union[XAAutomatorVariable, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("name", name)
 
     def by_settable(self, settable: bool) -> Union['XAAutomatorVariable', None]:
-        """Retrieves the first variable whose settable status matches the given boolean, if one exists.
-
-        :return: The desired variable, if it is found
-        :rtype: Union[XAAutomatorVariable, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("settable", settable)
 
     def by_value(self, value: Any) -> Union['XAAutomatorVariable', None]:
-        """Retrieves the first variable whose current value matches the given value, if one exists.
-
-        :return: The desired variable, if it is found
-        :rtype: Union[XAAutomatorVariable, None]
-        
-        .. versionadded:: 0.0.4
-        """
         if isinstance(value, XABase.XAObject):
             value = value.xa_elem
         return self.by_property("value", value)
@@ -1355,124 +865,40 @@ class XAAutomatorWorkflowList(XABase.XAList):
         super().__init__(properties, XAAutomatorWorkflow, filter)
 
     def current_action(self) -> XAAutomatorActionList:
-        """Retrieves the current action of each workflow in the list.
-
-        :return: The list of current actions.
-        :rtype: XAAutomatorActionList
-
-        .. versionadded:: 0.0.4
-        """
-        ls = self.xa_elem.arrayByApplyingSelector_("currentAction")
+        ls = self.xa_elem.arrayByApplyingSelector_("currentAction") or []
         return self._new_element(ls, XAAutomatorActionList)
 
     def execution_error_message(self) -> list[str]:
-        """Retrieves the execution error message of each workflow in the list.
-
-        :return: The list of error messages.
-        :rtype: list[str]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("executionErrorMessage"))
+        return list(self.xa_elem.arrayByApplyingSelector_("executionErrorMessage") or [])
 
     def execution_error_number(self) -> list[int]:
-        """Retrieves the execution error numbers of each workflow in the list.
-
-        :return: The list of error numbers.
-        :rtype: list[int]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("executionErrorNumber"))
+        return list(self.xa_elem.arrayByApplyingSelector_("executionErrorNumber") or [])
 
     def execution_id(self) -> list[str]:
-        """Retrieves the execution ID of each workflow in the list.
-
-        :return: The list of execution IDs.
-        :rtype: list[str]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("executionId"))
+        return list(self.xa_elem.arrayByApplyingSelector_("executionId") or [])
 
     def execution_result(self) -> list[Any]:
-        """Retrieves the execution result of each workflow in the list.
-
-        :return: The list of results.
-        :rtype: list[Any]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("executionResult"))
+        return list(self.xa_elem.arrayByApplyingSelector_("executionResult") or [])
 
     def name(self) -> list[str]:
-        """Retrieves the name of each workflow in the list.
-
-        :return: The list of workflow names.
-        :rtype: list[str]
-
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("name"))
+        return list(self.xa_elem.arrayByApplyingSelector_("name") or [])
 
     def by_current_action(self, current_action: XAAutomatorAction) -> Union['XAAutomatorWorkflow', None]:
-        """Retrieves the first workflow whose current action matches the given action, if one exists.
-
-        :return: The desired workflow, if it is found
-        :rtype: Union[XAAutomatorWorkflow, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("currentAction", current_action.xa_elem)
 
     def by_execution_error_message(self, execution_error_message: str) -> Union['XAAutomatorWorkflow', None]:
-        """Retrieves the first workflow whose error message matches the given message, if one exists.
-
-        :return: The desired workflow, if it is found
-        :rtype: Union[XAAutomatorWorkflow, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("executionErrorMessage", execution_error_message)
 
     def by_execution_error_number(self, execution_error_number: int) -> Union['XAAutomatorWorkflow', None]:
-        """Retrieves the first workflow whose error number matches the given error number, if one exists.
-
-        :return: The desired workflow, if it is found
-        :rtype: Union[XAAutomatorWorkflow, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("executionErrorNumber", execution_error_number)
 
     def by_execution_id(self, execution_id: str) -> Union['XAAutomatorWorkflow', None]:
-        """Retrieves the workflow whose execution ID matches the given ID, if one exists.
-
-        :return: The desired workflow, if it is found
-        :rtype: Union[XAAutomatorWorkflow, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("executionId", execution_id)
 
     def by_execution_result(self, result: Any) -> Union['XAAutomatorWorkflow', None]:
-        """Retrieves the first workflow whose execution result matches the given value, if one exists.
-
-        :return: The desired workflow, if it is found
-        :rtype: Union[XAAutomatorWorkflow, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("result", result)
 
     def by_name(self, name: str) -> Union['XAAutomatorWorkflow', None]:
-        """Retrieves the first workflow whose name matches the given name, if one exists.
-
-        :return: The desired workflow, if it is found
-        :rtype: Union[XAAutomatorWorkflow, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("name", name)
 
     def __repr__(self):
