@@ -91,183 +91,57 @@ class XADraftsDraftList(XABase.XAList):
         super().__init__(properties, XADraftsDraft, filter)
 
     def id(self) -> list[str]:
-        """Gets the ID of each draft in the list.
-
-        :return: A list of draft IDs
-        :rtype: list[str]
-        
-        .. versionadded:: 0.0.8
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("id"))
+        return list(self.xa_elem.arrayByApplyingSelector_("id") or [])
 
     def name(self) -> list[str]:
-        """Gets the name of each draft in the list.
-
-        :return: A list of draft names
-        :rtype: list[str]
-        
-        .. versionadded:: 0.0.8
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("name"))
+        return list(self.xa_elem.arrayByApplyingSelector_("name") or [])
 
     def content(self) -> list[str]:
-        """Gets the content of each draft in the list.
-
-        :return: A list of draft contents
-        :rtype: list[str]
-        
-        .. versionadded:: 0.0.8
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("content"))
+        return list(self.xa_elem.arrayByApplyingSelector_("content") or [])
 
     def flagged(self) -> list[bool]:
-        """Gets the flagged status of each draft in the list.
-
-        :return: A list of draft flagged statuses
-        :rtype: list[bool]
-        
-        .. versionadded:: 0.0.8
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("flagged"))
+        return list(self.xa_elem.arrayByApplyingSelector_("flagged") or [])
 
     def tags(self) -> list[list[str]]:
-        """Gets the tags of each draft in the list.
-
-        :return: A list of draft tags
-        :rtype: list[list[str]]
-        
-        .. versionadded:: 0.0.8
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("tags"))
+        return list(self.xa_elem.arrayByApplyingSelector_("tags") or [])
 
     def created_at(self) -> list[datetime]:
-        """Gets the creation date of each draft in the list.
-
-        :return: A list of draft creation dates
-        :rtype: list[datetime]
-        
-        .. versionadded:: 0.0.8
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("createdAt"))
+        return list(self.xa_elem.arrayByApplyingSelector_("createdAt") or [])
 
     def modified_at(self) -> list[datetime]:
-        """Gets the last modification date of each draft in the list.
-
-        :return: A list of draft modification dates
-        :rtype: list[datetime]
-        
-        .. versionadded:: 0.0.8
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("modifiedAt"))
+        return list(self.xa_elem.arrayByApplyingSelector_("modifiedAt") or [])
 
     def accessed_at(self) -> list[datetime]:
-        """Gets the last access date of each draft in the list.
-
-        :return: A list of draft last access dates
-        :rtype: list[datetime]
-        
-        .. versionadded:: 0.0.8
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("accessedAt"))
+        return list(self.xa_elem.arrayByApplyingSelector_("accessedAt") or [])
 
     def permalink(self) -> list[str]:
-        """Gets the URL of each draft in the list.
-
-        :return: A list of draft URLs
-        :rtype: list[str]
-        
-        .. versionadded:: 0.0.8
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("permalink"))
+        return list(self.xa_elem.arrayByApplyingSelector_("permalink") or [])
 
     def by_id(self, id: str) -> Union['XADraftsDraft', None]:
-        """Retrieves the draft whose ID matches the given ID, if one exists.
-
-        :return: The desired draft, if it is found
-        :rtype: Union[XADraftsDraft, None]
-        
-        .. versionadded:: 0.0.8
-        """
         return self.by_property("id", id)
 
     def by_name(self, name: str) -> Union['XADraftsDraft', None]:
-        """Retrieves the draft whose name matches the given name, if one exists.
-
-        :return: The desired draft, if it is found
-        :rtype: Union[XADraftsDraft, None]
-        
-        .. versionadded:: 0.0.8
-        """
         return self.by_property("name", name)
 
     def by_content(self, content: str) -> Union['XADraftsDraft', None]:
-        """Retrieves the draft whose content matches the given content, if one exists.
-
-        :return: The desired draft, if it is found
-        :rtype: Union[XADraftsDraft, None]
-        
-        .. versionadded:: 0.0.8
-        """
         return self.by_property("content", content)
 
     def by_flagged(self, flagged: bool) -> Union['XADraftsDraft', None]:
-        """Retrieves the first draft whose flagged status matches the given boolean value, if one exists.
-
-        :return: The desired draft, if it is found
-        :rtype: Union[XADraftsDraft, None]
-        
-        .. versionadded:: 0.0.8
-        """
         return self.by_property("flagged", flagged)
 
     def by_tags(self, tags: list[str]) -> Union['XADraftsDraft', None]:
-        """Retrieves the first draft whose list of tags matches the given list, if one exists.
-
-        :return: The desired draft, if it is found
-        :rtype: Union[XADraftsDraft, None]
-        
-        .. versionadded:: 0.0.8
-        """
         return self.by_property("tags", tags)
 
     def by_created_at(self, created_at: datetime) -> Union['XADraftsDraft', None]:
-        """Retrieves the draft whose creation date matches the given date, if one exists.
-
-        :return: The desired draft, if it is found
-        :rtype: Union[XADraftsDraft, None]
-        
-        .. versionadded:: 0.0.8
-        """
         return self.by_property("createdAt", created_at)
 
     def by_modified_at(self, modified_at: datetime) -> Union['XADraftsDraft', None]:
-        """Retrieves the draft whose last modification date matches the given date, if one exists.
-
-        :return: The desired draft, if it is found
-        :rtype: Union[XADraftsDraft, None]
-        
-        .. versionadded:: 0.0.8
-        """
         return self.by_property("modifiedAt", modified_at)
 
     def by_accessed_at(self, accessed_at: datetime) -> Union['XADraftsDraft', None]:
-        """Retrieves the draft whose last access date matches the given date, if one exists.
-
-        :return: The desired draft, if it is found
-        :rtype: Union[XADraftsDraft, None]
-        
-        .. versionadded:: 0.0.8
-        """
         return self.by_property("accessedAt", accessed_at)
 
     def by_permalink(self, permalink: str) -> Union['XADraftsDraft', None]:
-        """Retrieves the draft whose URL matches the given URL, if one exists.
-
-        :return: The desired draft, if it is found
-        :rtype: Union[XADraftsDraft, None]
-        
-        .. versionadded:: 0.0.8
-        """
         return self.by_property("permalink", permalink)
 
 class XADraftsDraft(XABase.XAObject):
