@@ -6,15 +6,12 @@ from enum import Enum
 from typing import Any, Union, Self
 
 import AppKit
-import logging
 
 from PyXA import XABase
 from PyXA.XABase import OSType
 
 from . import iWorkApplicationBase
 
-logger = logging.getLogger("numbers")
-
 class XANumbersApplication(iWorkApplicationBase.XAiWorkApplication):
     """A class for managing and interacting with Numbers.app.
 
@@ -189,16 +186,8 @@ class XANumbersDocumentList(iWorkApplicationBase.XAiWorkDocumentList):
     """
     def __init__(self, properties: dict, filter: Union[dict, None] = None):
         super().__init__(properties, filter, XANumbersDocument)
-        logger.debug("Got list of documents")
 
     def properties(self) -> list[dict]:
-        """Gets the properties dictionary of each document in the list.
-
-        :return: A list of document properties dictionaries
-        :rtype: list[dict]
-        
-        .. versionadded:: 0.1.0
-        """
         pyxa_dicts = [None] * len(self.xa_elem)
         for index, document in enumerate(self):
             pyxa_dicts[index] = {
@@ -214,35 +203,14 @@ class XANumbersDocumentList(iWorkApplicationBase.XAiWorkDocumentList):
         return pyxa_dicts
 
     def document_template(self) -> 'XANumbersTemplateList':
-        """Gets the document template of each document in the list.
-
-        :return: A list of templates used by the documents of the list
-        :rtype: XANumbersTemplateList
-        
-        .. versionadded:: 0.0.8
-        """
-        ls = self.xa_elem.arrayByApplyingSelector_("documentTemplate")
+        ls = self.xa_elem.arrayByApplyingSelector_("documentTemplate") or []
         return self._new_element(ls, XANumbersTemplateList)
 
     def active_sheet(self) -> 'XANumbersSheetList':
-        """Gets the active sheet of each document in the list.
-
-        :return: A list of active sheets in documents of the list
-        :rtype: XANumbersSheetList
-        
-        .. versionadded:: 0.0.8
-        """
-        ls = self.xa_elem.arrayByApplyingSelector_("activeSheet")
+        ls = self.xa_elem.arrayByApplyingSelector_("activeSheet") or []
         return self._new_element(ls, XANumbersSheetList)
 
     def by_properties(self, properties: dict) -> Union['XANumbersDocument', None]:
-        """Retrieves the first document whose properties dictionary matches the given properties, if one exists.
-
-        :return: The desired document, if it is found
-        :rtype: Union[XANumbersDocument, None]
-        
-        .. versionadded:: 0.1.0
-        """
         raw_dict = {}
 
         if "id" in properties:
@@ -280,23 +248,9 @@ class XANumbersDocumentList(iWorkApplicationBase.XAiWorkDocumentList):
                 return self._new_element(document, XANumbersDocument)
 
     def by_document_template(self, document_template: 'XANumbersTemplate') -> Union['XANumbersDocument', None]:
-        """Retrieves the first document whose template matches the given template, if one exists.
-
-        :return: The desired document, if it is found
-        :rtype: Union[XANumbersDocument, None]
-        
-        .. versionadded:: 0.0.8
-        """
         return self.by_property("documentTemplate", document_template.xa_elem)
 
     def by_active_sheet(self, active_sheet: 'XANumbersSheet') -> Union['XANumbersDocument', None]:
-        """Retrieves the first document whose active sheet matches the given sheet, if one exists.
-
-        :return: The desired document, if it is found
-        :rtype: Union[XANumbersDocument, None]
-        
-        .. versionadded:: 0.0.8
-        """
         return self.by_property("activeSheet", active_sheet.xa_elem)
 
     def __repr__(self):
@@ -401,17 +355,9 @@ class XANumbersTemplateList(XABase.XAList):
     """
     def __init__(self, properties: dict, filter: Union[dict, None] = None):
         super().__init__(properties, XANumbersTemplate, filter)
-        logger.debug("Got list of templates")
 
     def properties(self) -> list[dict]:
-        """Gets the properties dictionary of each template in the list.
-
-        :return: A list of template properties dictionaries
-        :rtype: list[dict]
-        
-        .. versionadded:: 0.1.0
-        """
-        raw_dicts = self.xa_elem.arrayByApplyingSelector_("properties")
+        raw_dicts = self.xa_elem.arrayByApplyingSelector_("properties") or []
         pyxa_dicts = [None] * len(self.xa_elem)
         for index, raw_dict in enumerate(raw_dicts):
             pyxa_dicts[index] = {
@@ -421,33 +367,12 @@ class XANumbersTemplateList(XABase.XAList):
         return pyxa_dicts
 
     def id(self) -> list[str]:
-        """Gets the ID of each template in the list.
-
-        :return: A list of template IDs
-        :rtype: list[str]
-        
-        .. versionadded:: 0.0.8
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("id"))
+        return list(self.xa_elem.arrayByApplyingSelector_("id") or [])
 
     def name(self) -> list[str]:
-        """Gets the name of each template in the list.
-
-        :return: A list of template names
-        :rtype: list[str]
-        
-        .. versionadded:: 0.0.8
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("name"))
+        return list(self.xa_elem.arrayByApplyingSelector_("name") or [])
 
     def by_properties(self, properties: dict) -> Union['XANumbersTemplate', None]:
-        """Retrieves the first template whose properties dictionary matches the given properties, if one exists.
-
-        :return: The desired template, if it is found
-        :rtype: Union[XANumbersTemplate, None]
-        
-        .. versionadded:: 0.1.0
-        """
         raw_dict = {}
 
         if "id" in properties:
@@ -461,23 +386,9 @@ class XANumbersTemplateList(XABase.XAList):
                 return self._new_element(template, XANumbersTemplate)
 
     def by_id(self, id: str) -> Union['XANumbersTemplate', None]:
-        """Retrieves the first template whose ID matches the given ID, if one exists.
-
-        :return: The desired template, if it is found
-        :rtype: Union[XANumbersTemplate, None]
-        
-        .. versionadded:: 0.0.8
-        """
         return self.by_property("id", id)
 
     def by_name(self, name: str) -> Union['XANumbersTemplate', None]:
-        """Retrieves the first template whose name matches the given name, if one exists.
-
-        :return: The desired template, if it is found
-        :rtype: Union[XANumbersTemplate, None]
-        
-        .. versionadded:: 0.0.8
-        """
         return self.by_property("name", name)
 
     def __repr__(self):
@@ -521,7 +432,6 @@ class XANumbersContainerList(iWorkApplicationBase.XAiWorkContainerList):
             obj_class = XANumbersContainer
         self._xa_ccls = XANumbersSheetList
         super().__init__(properties, filter, obj_class)
-        logger.debug("Got list of containers")
 
 class XANumbersContainer(iWorkApplicationBase.XAiWorkContainer):
     """A class for managing and interacting with containers in Numbers.
@@ -544,17 +454,9 @@ class XANumbersSheetList(XANumbersContainerList):
     """
     def __init__(self, properties: dict, filter: Union[dict, None] = None):
         super().__init__(properties, filter, XANumbersSheet)
-        logger.debug("Got list of sheets")
 
     def properties(self) -> list[dict]:
-        """Gets the properties dictionary of each sheet in the list.
-
-        :return: A list of sheet properties dictionaries
-        :rtype: list[dict]
-        
-        .. versionadded:: 0.1.0
-        """
-        raw_dicts = self.xa_elem.arrayByApplyingSelector_("properties")
+        raw_dicts = self.xa_elem.arrayByApplyingSelector_("properties") or []
         pyxa_dicts = [None] * len(self.xa_elem)
         for index, raw_dict in enumerate(raw_dicts):
             pyxa_dicts[index] = {
@@ -563,24 +465,10 @@ class XANumbersSheetList(XANumbersContainerList):
         return pyxa_dicts
 
     def body_text(self) -> XABase.XATextList:
-        """Gets the body text of each sheet in the list.
-
-        :return: A list of sheet body texts
-        :rtype: XABase.XATextList
-        
-        .. versionadded:: 0.0.8
-        """
-        ls = self.xa_elem.arrayByApplyingSelector_("bodyText")
+        ls = self.xa_elem.arrayByApplyingSelector_("bodyText") or []
         return self._new_element(ls, XABase.XATextList)
 
     def by_properties(self, properties: dict) -> Union['XANumbersSheet', None]:
-        """Retrieves the first sheet whose properties dictionary matches the given properties dictionary, if one exists.
-
-        :return: The desired sheet, if it is found
-        :rtype: Union[XANumbersSheet, None]
-        
-        .. versionadded:: 0.1.0
-        """
         raw_dict = {}
 
         if "name" in properties:
@@ -591,13 +479,6 @@ class XANumbersSheetList(XANumbersContainerList):
                 return self._new_element(sheet, XANumbersSheet)
 
     def by_body_text(self, body_text: Union[str, XABase.XAText]) -> Union['XANumbersSheet', None]:
-        """Retrieves the first sheet whose body text matches the given text, if one exists.
-
-        :return: The desired sheet, if it is found
-        :rtype: Union[XANumbersSheet, None]
-        
-        .. versionadded:: 0.0.8
-        """
         if isinstance(body_text, str):
             self.by_property('bodyText', body_text)
         else:
@@ -633,31 +514,6 @@ class XANumbersSheet(XANumbersContainer):
     def name(self, name: str):
         self.set_property('name', name)
 
-    # def duplicate(self) -> 'XANumbersPage':
-    #     """Duplicates the page, mimicking the action of copying and pasting the page manually.
-
-    #     :return: A reference to the PyXA page object that called this command.
-    #     :rtype: XANumbersPage
-
-    #     .. versionadded:: 0.0.8
-    #     """
-    #     new_page = self.xa_prnt.xa_prnt.xa_prnt.xa_prnt.make("page", {})
-    #     self.xa_prnt.xa_prnt.sheets().push(new_page)
-    #     for item in self.xa_elem.lines():
-    #         print("ya")
-    #         item.duplicateTo_withProperties_(new_page.xa_elem.lines()[0].positionAfter(), None)
-    #     return self
-
-    # def move_to(self, document):
-    #     self.xa_elem.moveTo_(document.xa_elem.sheets())
-
-    # def delete(self):
-    #     """Deletes the page.
-
-    #     .. versionadded:: 0.0.8
-    #     """
-    #     self.xa_elem.get().delete()
-
     def add_image(self, file_path: Union[str, XABase.XAPath, XABase.XAImage]) -> 'iWorkApplicationBase.XAiWorkImage':
         """Adds the image at the specified path to the page.
 
@@ -682,35 +538,4 @@ class XANumbersSheet(XANumbersContainer):
 
         image = self.images().push(parent.make("image", { "file": url }))
         image.xa_prnt = self
-        return image
-
-    # def add_chart(self, row_names: list[str], column_names: list[str], data: list[list[Any]], type: int = XANumbersApplication.ChartType.LINE_2D.value, group_by: int = XANumbersApplication.ChartGrouping.ROW.value) -> 'XANumbersChart':
-    #     """_summary_
-
-    #     _extended_summary_
-
-    #     :param row_names: A list of row names.
-    #     :type row_names: list[str]
-    #     :param column_names: A list of column names.
-    #     :type column_names: list[str]
-    #     :param data: A 2d array 
-    #     :type data: list[list[Any]]
-    #     :param type: The chart type, defaults to _NumbersLegacyChartType.NumbersLegacyChartTypeLine_2d.value
-    #     :type type: int, optional
-    #     :param group_by: The grouping schema, defaults to _NumbersLegacyChartGrouping.NumbersLegacyChartGroupingChartRow.value
-    #     :type group_by: int, optional
-    #     :return: A reference to the newly created chart object.
-    #     :rtype: XANumbersChart
-
-    #     .. versionadded:: 0.0.8
-    #     """
-    #     self.xa_prnt.set_property("currentSlide", self.xa_elem)
-    #     self.xa_elem.addChartRowNames_columnNames_data_type_groupBy_(row_names, column_names, data, type, group_by)
-    #     chart = self.xa_elem.charts()[-1].get()
-    #     properties = {
-    #         "parent": self,
-    #         "element": chart,
-    #         "appref": self.xa_aref,
-    #         "system_events": self.xa_sevt,
-    #     }
-    #     return XANumbersChart(properties)
\ No newline at end of file
+        return image
\ No newline at end of file
