@@ -31,19 +31,19 @@ class XARemindersApplication(XABaseScriptable.XASBApplication):
     def name(self) -> str:
         """The name of the application.
         """
-        return self.xa_elem.name()
+        return self.xa_scel.name()
 
     @property
     def frontmost(self) -> bool:
         """Whether Reminders is the active application.
         """
-        return self.xa_elem.frontmost()
+        return self.xa_scel.frontmost()
 
     @property
     def version(self) -> str:
         """The version number of Reminders.app.
         """
-        return self.xa_elem.version()
+        return self.xa_scel.version()
 
     @property
     def default_account(self) -> 'XARemindersAccount':
@@ -157,7 +157,7 @@ class XARemindersApplication(XABaseScriptable.XASBApplication):
 
         .. versionadded:: 0.0.1
         """
-        new_reminder = self.make("reminder", {"name": name, "dateDate": due_date})
+        new_reminder = self.make("reminder", {"name": name, "dueDate": due_date})
         if reminder_list is None:
             self.reminders().push(new_reminder)
             return self.reminders()[-1]
@@ -279,84 +279,28 @@ class XARemindersDocumentList(XABase.XAList):
         super().__init__(properties, XARemindersDocument, filter)
 
     def properties(self) -> list[dict]:
-        """Gets the properties of each document in the list.
-
-        :return: A list of document properties dictionaries
-        :rtype: list[dict]
-        
-        .. versionadded:: 0.0.6
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("properties"))
+        return list(self.xa_elem.arrayByApplyingSelector_("properties") or [])
 
     def name(self) -> list[dict]:
-        """Gets the name of each document in the list.
-
-        :return: A list of document names
-        :rtype: list[str]
-        
-        .. versionadded:: 0.0.6
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("name"))
+        return list(self.xa_elem.arrayByApplyingSelector_("name") or [])
 
     def modified(self) -> list[dict]:
-        """Gets the modified status of each document in the list.
-
-        :return: A list of document modified status boolean values
-        :rtype: list[bool]
-        
-        .. versionadded:: 0.0.6
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("modified"))
+        return list(self.xa_elem.arrayByApplyingSelector_("modified") or [])
 
     def file(self) -> list[XABase.XAPath]:
-        """Gets the file path of each document in the list.
-
-        :return: A list of document file paths
-        :rtype: list[XABase.XAPath]
-        
-        .. versionadded:: 0.0.6
-        """
-        ls = self.xa_elem.arrayByApplyingSelector_("file")
+        ls = self.xa_elem.arrayByApplyingSelector_("file") or []
         return [XABase.XAPath(x) for x in ls]
 
     def by_properties(self, properties: dict) -> Union['XARemindersDocument', None]:
-        """Retrieves the document whose properties matches the given properties dictionary, if one exists.
-
-        :return: The desired document, if it is found
-        :rtype: Union[XARemindersDocument, None]
-        
-        .. versionadded:: 0.0.6
-        """
         return self.by_property("properties", properties)
 
     def by_name(self, name: str) -> Union['XARemindersDocument', None]:
-        """Retrieves the document whose name matches the given name, if one exists.
-
-        :return: The desired document, if it is found
-        :rtype: Union[XARemindersDocument, None]
-        
-        .. versionadded:: 0.0.6
-        """
         return self.by_property("name", name)
 
     def by_modified(self, modified: bool) -> Union['XARemindersDocument', None]:
-        """Retrieves the document whose modified status matches the given boolean value, if one exists.
-
-        :return: The desired document, if it is found
-        :rtype: Union[XARemindersDocument, None]
-        
-        .. versionadded:: 0.0.6
-        """
         return self.by_property("modified", modified)
 
     def by_file(self, file: XABase.XAPath) -> Union['XARemindersDocument', None]:
-        """Retrieves the document whose file matches the given file path, if one exists.
-
-        :return: The desired document, if it is found
-        :rtype: Union[XARemindersDocument, None]
-        
-        .. versionadded:: 0.0.6
-        """
         return self.by_property("file", file.xa_elem)
 
     def __repr__(self):
@@ -439,63 +383,24 @@ class XARemindersAccountList(XABase.XAList):
         super().__init__(properties, XARemindersAccount, filter)
 
     def properties(self) -> list[dict]:
-        """Gets the properties of each account in the list.
-
-        :return: A list of account properties dictionaries
-        :rtype: list[dict]
-        
-        .. versionadded:: 0.0.6
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("properties"))
+        ls = self.xa_elem.arrayByApplyingSelector_("properties") or []
+        return [dict(x) for x in ls]
 
     def id(self) -> list[str]:
-        """Gets the ID of each account in the list.
-
-        :return: A list of account IDs
-        :rtype: list[str]
-        
-        .. versionadded:: 0.0.6
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("id"))
+        return list(self.xa_elem.arrayByApplyingSelector_("id") or [])
 
     def name(self) -> list[str]:
-        """Gets the name of each account in the list.
-
-        :return: A list of account names
-        :rtype: list[str]
-        
-        .. versionadded:: 0.0.6
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("name"))
+        return list(self.xa_elem.arrayByApplyingSelector_("name") or [])
 
     def by_properties(self, properties: dict) -> Union['XARemindersAccount', None]:
-        """Retrieves the account whose properties matches the given properties dictionary, if one exists.
-
-        :return: The desired account, if it is found
-        :rtype: Union[XARemindersAccount, None]
-        
-        .. versionadded:: 0.0.6
-        """
-        return self.by_property("properties", properties)
+        for account in self.xa_elem:
+            if account.properties() == properties:
+                return self._new_element(account, XARemindersAccount)
 
     def by_id(self, id: str) -> Union['XARemindersAccount', None]:
-        """Retrieves the account whose ID matches the given ID, if one exists.
-
-        :return: The desired account, if it is found
-        :rtype: Union[XARemindersAccount, None]
-        
-        .. versionadded:: 0.0.6
-        """
         return self.by_property("id", id)
 
     def by_name(self, name: str) -> Union['XARemindersAccount', None]:
-        """Retrieves the account whose name matches the given name, if one exists.
-
-        :return: The desired account, if it is found
-        :rtype: Union[XARemindersAccount, None]
-        
-        .. versionadded:: 0.0.6
-        """
         return self.by_property("name", name)
 
     def __repr__(self):
@@ -511,7 +416,7 @@ class XARemindersAccount(XABase.XAObject):
     def properties(self) -> dict:
         """All properties of the account.
         """
-        return self.xa_elem.properties()
+        return dict(self.xa_elem.properties())
 
     @property
     def id(self) -> str:
@@ -549,135 +454,49 @@ class XARemindersListList(XABase.XAList):
         super().__init__(properties, XARemindersList, filter)
 
     def properties(self) -> list[dict]:
-        """Gets the properties of each reminder list in the list.
-
-        :return: A list of reminder list properties dictionaries
-        :rtype: list[dict]
-        
-        .. versionadded:: 0.0.6
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("properties"))
+        ls = self.xa_elem.arrayByApplyingSelector_("properties") or []
+        return [dict(x) for x in ls]
 
     def id(self) -> list[str]:
-        """Gets the ID of each reminder list in the list.
-
-        :return: A list of reminder list IDs
-        :rtype: list[str]
-        
-        .. versionadded:: 0.0.6
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("id"))
+        return list(self.xa_elem.arrayByApplyingSelector_("id") or [])
 
     def name(self) -> list[dict]:
-        """Gets the name of each reminder list in the list.
-
-        :return: A list of reminder list names
-        :rtype: list[str]
-        
-        .. versionadded:: 0.0.6
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("name"))
+        return list(self.xa_elem.arrayByApplyingSelector_("name") or [])
 
     def container(self) -> XARemindersAccountList:
-        """Gets the parent container of each reminder list in the list.
-
-        :return: A list of accounts
-        :rtype: XARemindersAccountList
-        
-        .. versionadded:: 0.0.6
-        """
-        ls = self.xa_elem.arrayByApplyingSelector_("container")
+        ls = self.xa_elem.arrayByApplyingSelector_("container") or []
         return self._new_element(ls, XARemindersAccountList)
 
     def color(self) -> list[dict]:
-        """Gets the color of each reminder list in the list.
+        return list(self.xa_elem.arrayByApplyingSelector_("color") or [])
 
-        :return: A list of reminder list colors
-        :rtype: list[str]
-        
-        .. versionadded:: 0.0.6
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("color"))
-
-    def emblem(self) -> list[dict]:
-        """Gets the emblem name of each reminder list in the list.
-
-        :return: A list of reminder list emblems
-        :rtype: list[str]
-        
-        .. versionadded:: 0.0.6
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("emblem"))
+    def emblem(self) -> list[str]:
+        return list(self.xa_elem.arrayByApplyingSelector_("emblem") or [])
 
     def reminders(self) -> 'XARemindersReminderList':
-        """Gets the reminders of each reminder list in the list.
-
-        :return: A list of reminders
-        :rtype: XARemindersReminderList
-        
-        .. versionadded:: 0.0.6
-        """
-        ls = self.xa_elem.arrayByApplyingSelector_("reminders")
+        ls = self.xa_elem.arrayByApplyingSelector_("reminders") or []
         return self._new_element(ls, XARemindersReminderList)
 
-    def by_properties(self, properties: dict) -> Union['XARemindersListList', None]:
-        """Retrieves the list whose properties matches the given properties dictionary, if one exists.
+    def by_properties(self, properties: dict) -> Union['XARemindersList', None]:
+        for ls in self.xa_elem:
+            if ls.properties() == properties:
+                return self._new_element(ls, XARemindersList)
 
-        :return: The desired list, if it is found
-        :rtype: Union[XARemindersListList, None]
-        
-        .. versionadded:: 0.0.6
-        """
-        return self.by_property("properties", properties)
-
-    def by_id(self, id: str) -> Union['XARemindersListList', None]:
-        """Retrieves the list whose ID matches the given ID, if one exists.
-
-        :return: The desired list, if it is found
-        :rtype: Union[XARemindersListList, None]
-        
-        .. versionadded:: 0.0.6
-        """
+    def by_id(self, id: str) -> Union['XARemindersList', None]:
         return self.by_property("id", id)
 
-    def by_name(self, name: str) -> Union['XARemindersListList', None]:
-        """Retrieves the list whose name matches the given name, if one exists.
-
-        :return: The desired list, if it is found
-        :rtype: Union[XARemindersListList, None]
-        
-        .. versionadded:: 0.0.6
-        """
+    def by_name(self, name: str) -> Union['XARemindersList', None]:
         return self.by_property("name", name)
 
-    def by_container(self, container: 'XARemindersList') -> Union['XARemindersListList', None]:
-        """Retrieves the list whose parent container matches the given account, if one exists.
+    def by_container(self, container: 'XARemindersList') -> Union['XARemindersList', None]:
+        for ls in self.xa_elem:
+            if ls.container().get() == container.xa_elem.get():
+                return self._new_element(ls, XARemindersList) 
 
-        :return: The desired list, if it is found
-        :rtype: Union[XARemindersListList, None]
-        
-        .. versionadded:: 0.0.6
-        """
-        return self.by_property("container", container.xa_elem)
-
-    def by_color(self, color: str) -> Union['XARemindersListList', None]:
-        """Retrieves the list whose color matches the given color, if one exists.
-
-        :return: The desired list, if it is found
-        :rtype: Union[XARemindersListList, None]
-        
-        .. versionadded:: 0.0.6
-        """
+    def by_color(self, color: str) -> Union['XARemindersList', None]:
         return self.by_property("color", color)
 
-    def by_emblem(self, emblem: str) -> Union['XARemindersListList', None]:
-        """Retrieves the list whose emblem matches the given emblem, if one exists.
-
-        :return: The desired list, if it is found
-        :rtype: Union[XARemindersListList, None]
-        
-        .. versionadded:: 0.0.6
-        """
+    def by_emblem(self, emblem: str) -> Union['XARemindersList', None]:
         return self.by_property("emblem", emblem)
 
     def delete(self):
@@ -697,20 +516,21 @@ class XARemindersList(XABase.XAObject):
         super().__init__(properties)
 
         # EventKit Properties
-        lists = XABase.XAPredicate().from_args("calendarIdentifier", self.xa_elem.id()).evaluate(self._xa_estr.allCalendars())
-        if len(lists) > 0:
-            elem = lists[0]
+        if hasattr(self.xa_elem, "id"):
+            lists = XABase.XAPredicate().from_args("calendarIdentifier", self.xa_elem.id()).evaluate(self.xa_estr.calendars())
+            if len(lists) > 0:
+                elem = lists[0]
 
-            self.summary = elem.summary() #: An overview of the list's information
-            self.subscription_url = elem.subscriptionURL() #: The URL of the list used to subscribe to it
-            self.sharing_status: bool = elem.sharingStatus() #: Whether the list is shared
-            self.sharees = elem.sharees() #: A list of individuals with whom the list is shared with
+                self.summary = elem.summary() #: An overview of the list's information
+                self.subscription_url = elem.subscriptionURL() #: The URL of the list used to subscribe to it
+                self.sharing_status: bool = elem.sharingStatus() #: Whether the list is shared
+                self.sharees = elem.sharees() #: A list of individuals with whom the list is shared with
 
     @property
     def properties(self) -> dict:
         """All properties of the list.
         """
-        return self.xa_elem.properties()
+        return dict(self.xa_elem.properties())
 
     @property
     def id(self) -> str:
@@ -799,294 +619,108 @@ class XARemindersReminderList(XABase.XAList):
         super().__init__(properties, XARemindersReminder, filter)
 
     def properties(self) -> list[dict]:
-        """Gets the properties of each reminder in the list.
-
-        :return: A list of reminder properties dictionaries
-        :rtype: list[dict]
-        
-        .. versionadded:: 0.0.6
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("properties"))
+        ls = self.xa_elem.arrayByApplyingSelector_("properties") or []
+        return [dict(x) for x in ls]
 
     def name(self) -> list[str]:
-        """Gets the name of each reminder in the list.
-
-        :return: A list of reminder names
-        :rtype: list[str]
-        
-        .. versionadded:: 0.0.6
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("name"))
+        return list(self.xa_elem.arrayByApplyingSelector_("name") or [])
 
     def id(self) -> list[str]:
-        """Gets the ID of each reminder in the list.
-
-        :return: A list of reminder IDs
-        :rtype: list[str]
-        
-        .. versionadded:: 0.0.6
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("id"))
+        return list(self.xa_elem.arrayByApplyingSelector_("id") or [])
 
     def container(self) -> XARemindersListList:
-        """Gets the parent list of each reminder in the list.
-
-        :return: A list of reminder lists
-        :rtype: XARemindersListList
-        
-        .. versionadded:: 0.0.6
-        """
-        ls = self.xa_elem.arrayByApplyingSelector_("creationDate")
+        ls = self.xa_elem.arrayByApplyingSelector_("container") or []
         return self._new_element(ls, XARemindersListList)
 
     def creation_date(self) -> list[datetime]:
-        """Gets the creation date of each reminder in the list.
-
-        :return: A list of creation dates
-        :rtype: list[datetime]
-        
-        .. versionadded:: 0.0.6
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("creationDate"))
+        return list(self.xa_elem.arrayByApplyingSelector_("creationDate") or [])
 
     def modification_date(self) -> list[datetime]:
-        """Gets the last modification date of each reminder in the list.
-
-        :return: A list of modification dates
-        :rtype: list[datetime]
-        
-        .. versionadded:: 0.0.6
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("modificationDate"))
+        return list(self.xa_elem.arrayByApplyingSelector_("modificationDate") or [])
 
     def body(self) -> list[str]:
-        """Gets the body text of each reminder in the list.
-
-        :return: A list of reminder body texts
-        :rtype: list[str]
-        
-        .. versionadded:: 0.0.6
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("body"))
+        return list(self.xa_elem.arrayByApplyingSelector_("body") or [])
 
     def completed(self) -> list[bool]:
-        """Gets the completed status of each reminder in the list.
-
-        :return: A list of reminder completed status boolean values
-        :rtype: list[bool]
-        
-        .. versionadded:: 0.0.6
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("completed"))
+        return list(self.xa_elem.arrayByApplyingSelector_("completed") or [])
 
     def completion_date(self) -> list[datetime]:
-        """Gets the completion date of each reminder in the list.
-
-        :return: A list of completion dates
-        :rtype: list[datetime]
-        
-        .. versionadded:: 0.0.6
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("completionDate"))
+        return list(self.xa_elem.arrayByApplyingSelector_("completionDate") or [])
 
     def due_date(self) -> list[datetime]:
-        """Gets the due date of each reminder in the list.
-
-        :return: A list of due dates
-        :rtype: list[datetime]
-        
-        .. versionadded:: 0.0.6
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("dueDate"))
+        return list(self.xa_elem.arrayByApplyingSelector_("dueDate") or [])
 
     def allday_due_date(self) -> list[datetime]:
-        """Gets the allday due date of each reminder in the list.
-
-        :return: A list of allday due dates
-        :rtype: list[datetime]
-        
-        .. versionadded:: 0.0.6
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("alldayDueDate"))
+        return list(self.xa_elem.arrayByApplyingSelector_("alldayDueDate") or [])
 
     def remind_me_date(self) -> list[datetime]:
-        """Gets the remind me date of each reminder in the list.
-
-        :return: A list of remind me dates
-        :rtype: list[datetime]
-        
-        .. versionadded:: 0.0.6
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("remindMeDate"))
+        return list(self.xa_elem.arrayByApplyingSelector_("remindMeDate") or [])
 
     def priority(self) -> list[int]:
-        """Gets the priority of each reminder in the list.
-
-        :return: A list of reminder priorities
-        :rtype: list[int]
-        
-        .. versionadded:: 0.0.6
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("priority"))
+        return list(self.xa_elem.arrayByApplyingSelector_("priority") or [])
 
     def flagged(self) -> list[bool]:
-        """Gets the flagged status of each reminder in the list.
-
-        :return: A list of reminder flagged status boolean values
-        :rtype: list[bool]
-        
-        .. versionadded:: 0.0.6
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("flagged"))
+        return list(self.xa_elem.arrayByApplyingSelector_("flagged") or [])
 
     def alarms(self) -> list['XARemindersAlarmList']:
-        """Gets the alarms of each reminder in the list.
-
-        :return: A list of lists of alarms
-        :rtype: list[XARemindersAlarmList]
-        
-        .. versionadded:: 0.0.6
-        """
         return [x.alarms() for x in self]
 
-    def by_properties(self, properties: dict) -> Union['XARemindersReminderList', None]:
-        """Retrieves the reminder whose properties matches the given properties dictionary, if one exists.
+    def by_properties(self, properties: dict) -> Union['XARemindersReminder', None]:
+        for reminder in self.xa_elem:
+            if reminder.properties() == properties:
+                return self._new_element(reminder, XARemindersReminder)
 
-        :return: The desired reminder, if it is found
-        :rtype: Union[XARemindersReminderList, None]
-        
-        .. versionadded:: 0.0.6
-        """
-        return self.by_property("properties", properties)
-
-    def by_name(self, name: str) -> Union['XARemindersReminderList', None]:
-        """Retrieves the reminder whose name matches the given name, if one exists.
-
-        :return: The desired reminder, if it is found
-        :rtype: Union[XARemindersReminderList, None]
-        
-        .. versionadded:: 0.0.6
-        """
+    def by_name(self, name: str) -> Union['XARemindersReminder', None]:
         return self.by_property("name", name)
 
-    def by_id(self, id: str) -> Union['XARemindersReminderList', None]:
-        """Retrieves the reminder whose ID matches the given ID, if one exists.
-
-        :return: The desired reminder, if it is found
-        :rtype: Union[XARemindersReminderList, None]
-        
-        .. versionadded:: 0.0.6
-        """
+    def by_id(self, id: str) -> Union['XARemindersReminder', None]:
         return self.by_property("id", id)
 
-    def by_container(self, container: 'XARemindersList') -> Union['XARemindersReminderList', None]:
-        """Retrieves the reminder whose parent container matches the given list, if one exists.
+    def by_container(self, container: 'XARemindersList') -> Union['XARemindersReminder', None]:
+        for reminder in self.xa_elem:
+            if reminder.container().get() == container.xa_elem.get():
+                return self._new_element(reminder, XARemindersReminder)
 
-        :return: The desired reminder, if it is found
-        :rtype: Union[XARemindersReminderList, None]
-        
-        .. versionadded:: 0.0.6
-        """
-        return self.by_property("container", container.xa_elem)
+    def by_creation_date(self, creation_date: datetime) -> Union['XARemindersReminder', None]:
+        for reminder in self.xa_elem:
+            if reminder.creationDate() == creation_date:
+                return self._new_element(reminder, XARemindersReminder)
 
-    def by_creation_date(self, creation_date: datetime) -> Union['XARemindersReminderList', None]:
-        """Retrieves the reminder whose creation date matches the given date, if one exists.
+    def by_modification_date(self, modification_date: datetime) -> Union['XARemindersReminder', None]:
+        for reminder in self.xa_elem:
+            if reminder.modificationDate() == modification_date:
+                return self._new_element(reminder, XARemindersReminder)
 
-        :return: The desired reminder, if it is found
-        :rtype: Union[XARemindersReminderList, None]
-        
-        .. versionadded:: 0.0.6
-        """
-        return self.by_property("creationDate", creation_date)
-
-    def by_modification_date(self, modification_date: datetime) -> Union['XARemindersReminderList', None]:
-        """Retrieves the reminder whose modification date matches the given date, if one exists.
-
-        :return: The desired reminder, if it is found
-        :rtype: Union[XARemindersReminderList, None]
-        
-        .. versionadded:: 0.0.6
-        """
-        return self.by_property("modificationDate", modification_date)
-
-    def by_body(self, body: str) -> Union['XARemindersReminderList', None]:
-        """Retrieves the reminder whose body content matches the given string, if one exists.
-
-        :return: The desired reminder, if it is found
-        :rtype: Union[XARemindersReminderList, None]
-        
-        .. versionadded:: 0.0.6
-        """
+    def by_body(self, body: str) -> Union['XARemindersReminder', None]:
         return self.by_property("body", body)
 
-    def by_completed(self, completed: bool) -> Union['XARemindersReminderList', None]:
-        """Retrieves the reminder whose completed status matches the given boolean value, if one exists.
-
-        :return: The desired reminder, if it is found
-        :rtype: Union[XARemindersReminderList, None]
-        
-        .. versionadded:: 0.0.6
-        """
+    def by_completed(self, completed: bool) -> Union['XARemindersReminder', None]:
         return self.by_property("completed", completed)
 
-    def by_completion_date(self, completed_date: datetime) -> Union['XARemindersReminderList', None]:
-        """Retrieves the reminder whose completion date matches the given date, if one exists.
+    def by_completion_date(self, completion_date: datetime) -> Union['XARemindersReminder', None]:
+        for reminder in self.xa_elem:
+            if reminder.completionDate() == completion_date:
+                return self._new_element(reminder, XARemindersReminder)
 
-        :return: The desired reminder, if it is found
-        :rtype: Union[XARemindersReminderList, None]
-        
-        .. versionadded:: 0.0.6
-        """
-        return self.by_property("completedDate", completed_date)
+    def by_due_date(self, due_date: datetime) -> Union['XARemindersReminder', None]:
+        for reminder in self.xa_elem:
+            if reminder.dueDate() == due_date:
+                return self._new_element(reminder, XARemindersReminder)
 
-    def by_due_date(self, due_date: datetime) -> Union['XARemindersReminderList', None]:
-        """Retrieves the reminder whose due date matches the given date, if one exists.
+    def by_allday_due_date(self, allday_due_date: datetime) -> Union['XARemindersReminder', None]:
+        for reminder in self.xa_elem:
+            if reminder.alldayDueDate() == allday_due_date:
+                return self._new_element(reminder, XARemindersReminder)
 
-        :return: The desired reminder, if it is found
-        :rtype: Union[XARemindersReminderList, None]
-        
-        .. versionadded:: 0.0.6
-        """
-        return self.by_property("dueDate", due_date)
+    def by_remind_me_date(self, remind_me_date: datetime) -> Union['XARemindersReminder', None]:
+        for reminder in self.xa_elem:
+            if reminder.remindMeDate() == remind_me_date:
+                return self._new_element(reminder, XARemindersReminder)
 
-    def by_allday_due_date(self, allday_due_date: datetime) -> Union['XARemindersReminderList', None]:
-        """Retrieves the reminder whose allday due date matches the given date, if one exists.
-
-        :return: The desired reminder, if it is found
-        :rtype: Union[XARemindersReminderList, None]
-        
-        .. versionadded:: 0.0.6
-        """
-        return self.by_property("alldayDueDate", allday_due_date)
-
-    def by_remind_me_date(self, remind_me_date: datetime) -> Union['XARemindersReminderList', None]:
-        """Retrieves the reminder whose remind me date matches the given date, if one exists.
-
-        :return: The desired reminder, if it is found
-        :rtype: Union[XARemindersReminderList, None]
-        
-        .. versionadded:: 0.0.6
-        """
-        return self.by_property("remindMeDate", remind_me_date)
-
-    def by_priority(self, priority: int) -> Union['XARemindersReminderList', None]:
-        """Retrieves the reminder whose priority matches the given priority, if one exists.
-
-        :return: The desired reminder, if it is found
-        :rtype: Union[XARemindersReminderList, None]
-        
-        .. versionadded:: 0.0.6
-        """
+    def by_priority(self, priority: int) -> Union['XARemindersReminder', None]:
         return self.by_property("priority", priority)
 
-    def by_flagged(self, flagged: bool) -> Union['XARemindersReminderList', None]:
-        """Retrieves the reminder whose flagged status matches the given boolean value, if one exists.
-
-        :return: The desired reminder, if it is found
-        :rtype: Union[XARemindersReminderList, None]
-        
-        .. versionadded:: 0.0.6
-        """
+    def by_flagged(self, flagged: bool) -> Union['XARemindersReminder', None]:
         return self.by_property("flagged", flagged)
 
     def delete(self):
@@ -1126,7 +760,7 @@ class XARemindersReminder(XABase.XAObject):
         """
         if self.__properties is None:
             self.__properties = self.xa_elem.properties()
-        return self.__properties.copy()
+        return dict(self.__properties.copy())
 
     @property
     def name(self) -> str:
@@ -1188,7 +822,7 @@ class XARemindersReminder(XABase.XAObject):
         """
         if self.__properties is None:
             self.__properties = self.xa_elem.properties()
-        return self.__properties["body"]
+        return self.__properties["body"] or ""
 
     @body.setter
     def body(self, body: str):
@@ -1209,7 +843,7 @@ class XARemindersReminder(XABase.XAObject):
         self.set_property('completed', completed)
 
     @property
-    def completion_date(self) -> datetime:
+    def completion_date(self) -> Union[datetime, None]:
         """The completion date of the reminder.
 
         .. versionadded:: 0.0.6
@@ -1223,7 +857,7 @@ class XARemindersReminder(XABase.XAObject):
         self.set_property('completionDate', completion_date)
 
     @property
-    def due_date(self) -> datetime:
+    def due_date(self) -> Union[datetime, None]:
         """The due date of the reminder; will set both date and time.
 
         .. versionadded:: 0.0.6
@@ -1238,7 +872,7 @@ class XARemindersReminder(XABase.XAObject):
         self.set_property('dueDate', due_date)
 
     @property
-    def allday_due_date(self) -> datetime:
+    def allday_due_date(self) -> Union[datetime, None]:
         """The all-day due date of the reminder; will only set a date.
 
         .. versionadded:: 0.0.6
@@ -1252,7 +886,7 @@ class XARemindersReminder(XABase.XAObject):
         self.set_property('alldayDueDate', allday_due_date)
 
     @property
-    def remind_me_date(self) -> datetime:
+    def remind_me_date(self) -> Union[datetime, None]:
         """The remind date of the reminder.
 
         .. versionadded:: 0.0.6
@@ -1331,8 +965,8 @@ class XARemindersReminder(XABase.XAObject):
             return self._new_element(reminder.recurrenceRule(), XARemindersRecurrenceRule)
 
     def __get_ek_reminder(self) -> EventKit.EKReminder:
-        predicate = self._xa_estr.predicateForRemindersInCalendars_(None)
-        reminders = self._xa_estr.remindersMatchingPredicate_(predicate)
+        predicate = self.xa_estr.predicateForRemindersInCalendars_(None)
+        reminders = self.xa_estr.remindersMatchingPredicate_(predicate)
 
         reminder_id = self.xa_elem.properties()["id"] if self.__properties is None else self.__properties["id"]
 
@@ -1436,7 +1070,7 @@ class XARemindersRecurrenceRule(XABase.XAObject):
             "yearly": 3,
         }
         self.xa_elem.setFrequency_(freq_ids[frequency])
-        self._xa_estr.saveReminder_commit_error_(self.xa_prnt.xa_elem, True, None)
+        self.xa_estr.saveReminder_commit_error_(self.xa_prnt.xa_elem, True, None)
 
     def set_interval(self, interval: int):
         """Sets the interval of recurrence.
@@ -1447,7 +1081,7 @@ class XARemindersRecurrenceRule(XABase.XAObject):
         .. versionadded:: 0.0.2
         """
         self.xa_elem.setInterval_(interval)
-        self._xa_estr.saveReminder_commit_error_(self.xa_prnt.xa_elem, True, None)
+        self.xa_estr.saveReminder_commit_error_(self.xa_prnt.xa_elem, True, None)
 
     def set_end_date(self, end_date: datetime):
         """Sets the date and time when the recurrence ends.
@@ -1458,7 +1092,7 @@ class XARemindersRecurrenceRule(XABase.XAObject):
         .. versionadded:: 0.0.2
         """
         self.xa_elem.setEndDate_(end_date)
-        self._xa_estr.saveReminder_commit_error_(self.xa_prnt.xa_elem, True, None)
+        self.xa_estr.saveReminder_commit_error_(self.xa_prnt.xa_elem, True, None)
 
     def __repr__(self):
         return "<" + str(type(self)) + f"freq={self.xa_elem.frequencyString()}, interval={self.interval}, end_date={self.end_date}, id={self.id}>"
@@ -1477,103 +1111,33 @@ class XARemindersAlarmList(XABase.XAList):
         super().__init__(properties, XARemindersAlarm, filter)
 
     def id(self) -> list[str]:
-        """Gets the ID of each alarm in the list.
-
-        :return: A list of alarm IDs
-        :rtype: list[str]
-        
-        .. versionadded:: 0.0.6
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("sharedUID"))
+        return list(self.xa_elem.arrayByApplyingSelector_("sharedUID") or [])
 
     def snoozed(self) -> list[bool]:
-        """Gets the snoozed status of each alarm in the list.
-
-        :return: A list of alarm snoozed status boolean values
-        :rtype: list[str]
-        
-        .. versionadded:: 0.0.6
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("isSnoozed"))
+        return list(self.xa_elem.arrayByApplyingSelector_("isSnoozed") or [])
 
     def date(self) -> list[datetime]:
-        """Gets the date of each alarm in the list.
-
-        :return: A list of alarm dates
-        :rtype: list[datetime]
-        
-        .. versionadded:: 0.0.6
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("absoluteDate"))
+        return list(self.xa_elem.arrayByApplyingSelector_("absoluteDate") or [])
 
     def proximity_direction(self) -> list[str]:
-        """Gets the proximity direction of each alarm in the list.
-
-        :return: A list of directions
-        :rtype: list[str]
-        
-        .. versionadded:: 0.0.6
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("proximityString"))
+        return list(self.xa_elem.arrayByApplyingSelector_("proximityString") or [])
 
     def location(self) -> list[XABase.XALocation]:
-        """Gets the location of each alarm in the list.
-
-        :return: A list of alarm locations
-        :rtype: list[XABase.XALocation]
-        
-        .. versionadded:: 0.0.6
-        """
         return [x.location for x in self]
 
     def by_id(self, id: str) -> Union['XARemindersAlarm', None]:
-        """Retrieves the alarm whose ID matches the given ID, if one exists.
-
-        :return: The desired alarm, if it is found
-        :rtype: Union[XARemindersAlarm, None]
-        
-        .. versionadded:: 0.0.6
-        """
         return self.by_property("sharedUID", id)
 
     def by_snoozed(self, snoozed: bool) -> Union['XARemindersAlarm', None]:
-        """Retrieves the alarm whose snoozed status matches the given boolean value, if one exists.
-
-        :return: The desired alarm, if it is found
-        :rtype: Union[XARemindersAlarm, None]
-        
-        .. versionadded:: 0.0.6
-        """
         return self.by_property("isSnoozed", snoozed)
 
     def by_date(self, date: datetime) -> Union['XARemindersAlarm', None]:
-        """Retrieves the alarm whose date matches the given date, if one exists.
-
-        :return: The desired alarm, if it is found
-        :rtype: Union[XARemindersAlarm, None]
-        
-        .. versionadded:: 0.0.6
-        """
         return self.by_property("absoluteDate", date)
 
     def by_proximity_direction(self, proximity_direction: str) -> Union['XARemindersAlarm', None]:
-        """Retrieves the alarm whose proximity direction matches the given direction, if one exists.
-
-        :return: The desired alarm, if it is found
-        :rtype: Union[XARemindersAlarm, None]
-        
-        .. versionadded:: 0.0.6
-        """
         return self.by_property("proximityString", proximity_direction)
 
     def by_location(self, location: XABase.XALocation) -> Union['XARemindersAlarm', None]:
-        """Retrieves the alarm whose location matches the given location, if one exists.
-
-        :return: The desired alarm, if it is found
-        :rtype: Union[XARemindersAlarm, None]
-        
-        .. versionadded:: 0.0.6
-        """
         return self.by_property("structuredLocation", location.xa_elem)
 
     def __repr__(self):
@@ -1634,7 +1198,7 @@ class XARemindersAlarm(XABase.XAObject):
         .. versionadded:: 0.0.2
         """
         self.xa_elem.setAbsoluteDate_(date)
-        self._xa_estr.saveReminder_commit_error_(self.xa_prnt.xa_elem, True, None)
+        self.xa_estr.saveReminder_commit_error_(self.xa_prnt.xa_prnt.xa_elem, True, None)
 
     def set_location(self, location: XABase.XALocation):
         """Sets the location and radius of the alarm.
@@ -1646,7 +1210,7 @@ class XARemindersAlarm(XABase.XAObject):
         """
         location.raw_value = self.location.raw_value
         location.prepare_for_export()
-        self._xa_estr.saveReminder_commit_error_(self.xa_prnt.xa_elem, True, None)
+        self.xa_estr.saveReminder_commit_error_(self.xa_prnt.xa_prnt.xa_elem, True, None)
 
     def __repr__(self):
         return "<" + str(type(self)) + "id=" + self.id + ">"
\ No newline at end of file
