@@ -8,14 +8,11 @@ from typing import Any, Union, Self
 import threading
 
 import AppKit
-import logging
 
 from PyXA import XABase
 from PyXA import XABaseScriptable
 from ..XAProtocols import XACanOpenPath, XAClipboardCodable, XACloseable
 
-logger = logging.getLogger("safari")
-
 class XASafariApplication(XABaseScriptable.XASBApplication, XABaseScriptable.XASBPrintable, XABase.XAObject, XACanOpenPath):
     """A class for interacting with Safari.app.
 
@@ -27,8 +24,6 @@ class XASafariApplication(XABaseScriptable.XASBApplication, XABaseScriptable.XAS
         super().__init__(properties)
         self.xa_wcls = XASafariWindow
 
-        logging.debug("Initialized XASafariApplication")
-
     @property
     def frontmost(self) -> bool:
         """Whether Safari is the active application.
@@ -84,9 +79,7 @@ class XASafariApplication(XABaseScriptable.XASBApplication, XABaseScriptable.XAS
         >>> app.open("/Users/exampleuser/Documents/WebPage.html")
 
         .. versionadded:: 0.0.1
-        """
-        logger.debug(f"Attempting to open url of type {type(url)}")
-        
+        """        
         if isinstance(url, str):
             url = XABase.XAURL(url)
 
@@ -94,7 +87,6 @@ class XASafariApplication(XABaseScriptable.XASBApplication, XABaseScriptable.XAS
         new_tab = self.make("tab", {"URL": url.url})
         tab = self.front_window.tabs().push(new_tab)
         self.front_window.current_tab = tab
-        logger.debug(f"Opened URL")
         return tab
 
     def show_bookmarks(self) -> 'XASafariApplication':
@@ -348,7 +340,6 @@ class XASafariGeneric(XACloseable, XABase.XAObject):
     """
     def __init__(self, properties):
         super().__init__(properties)
-        logging.debug("Initialized XASafariGeneric")
 
     def search(self, term: str) -> Self:
         """Searches for the specified term in the current tab or document.
@@ -421,130 +412,44 @@ class XASafariDocumentList(XABase.XAList, XAClipboardCodable):
     def __init__(self, properties: dict, filter: Union[dict, None] = None):
         super().__init__(properties, XASafariDocument, filter)
 
-        logging.debug("Initialized XASafariDocumentList")
-
     def name(self) -> list[str]:
-        """Gets the name of each document in the list.
-
-        :return: A list of document names
-        :rtype: list[str]
-        
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("name"))
+        return list(self.xa_elem.arrayByApplyingSelector_("name") or [])
 
     def modified(self) -> list[bool]:
-        """Gets the modified status of each document in the list.
-
-        :return: A list of modified status booleans
-        :rtype: list[bool]
-        
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("modified"))
+        return list(self.xa_elem.arrayByApplyingSelector_("modified") or [])
 
     def file(self) -> list[str]:
-        """Gets the file path of each document in the list.
-
-        :return: A list of file paths
-        :rtype: list[str]
-        
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("file"))
+        return list(self.xa_elem.arrayByApplyingSelector_("file") or [])
 
     def source(self) -> list[str]:
-        """Gets the source HTML of each document in the list.
-
-        :return: A list of document source HTML
-        :rtype: list[str]
-        
-        .. versionadded:: 0.0.4
-        """
         return [x.source() for x in self.xa_elem]
 
     def url(self) -> list[XABase.XAURL]:
-        """Gets the file URL of each document in the list.
-
-        :return: A list of document URLs
-        :rtype: list[XABase.XAURL]
-        
-        .. versionadded:: 0.0.4
-        """
-        ls = self.xa_elem.arrayByApplyingSelector_("URL")
+        ls = self.xa_elem.arrayByApplyingSelector_("URL") or []
         return [XABase.XAURL(x) for x in ls]
 
     def text(self) -> list[XABase.XAText]:
-        """Gets the visible text of each document in the list.
-
-        :return: A list of document text
-        :rtype: list[XABase.XAText]
-        
-        .. versionadded:: 0.0.4
-        """
         ls = [x.text() for x in self.xa_elem]
         return [XABase.XAText(x) for x in ls]
 
     def by_name(self, name: str) -> Union['XASafariDocument', None]:
-        """Retrieves the document whose name matches the given name, if one exists.
-
-        :return: The desired document, if it is found
-        :rtype: Union[XASafariDocument, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("name", name)
 
     def by_modified(self, modified: bool) -> Union['XASafariDocument', None]:
-        """Retrieves the tab whose modified status matches the given boolean value, if one exists.
-
-        :return: The desired document, if it is found
-        :rtype: Union[XASafariDocument, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("modified", modified)
 
     def by_file(self, file: str) -> Union['XASafariDocument', None]:
-        """Retrieves the tab whose file matches the given file path, if one exists.
-
-        :return: The desired document, if it is found
-        :rtype: Union[XASafariDocument, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("file", file)
 
     def by_source(self, source: str) -> Union['XASafariDocument', None]:
-        """Retrieves the tab whose source HTML matches the given HTML, if one exists.
-
-        :return: The desired document, if it is found
-        :rtype: Union[XASafariDocument, None]
-        
-        .. versionadded:: 0.0.4
-        """
         for doc in self.xa_elem:
             if doc.source() == source:
                 return self._new_element(doc, XASafariDocument)
 
     def by_url(self, url: XABase.XAURL) -> Union['XASafariDocument', None]:
-        """Retrieves the tab whose URL matches the given URL, if one exists.
-
-        :return: The desired document, if it is found
-        :rtype: Union[XASafariDocument, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("URL", str(url.xa_elem))
     
     def by_text(self, text: Union[str, XABase.XAText]) -> Union['XASafariDocument', None]:
-        """Retrieves the tab whose visible text matches the given text, if one exists.
-
-        :return: The desired document, if it is found
-        :rtype: Union[XASafariDocument, None]
-        
-        .. versionadded:: 0.0.4
-        """
         for doc in self.xa_elem:
             if doc.text() == str(text):
                 return self._new_element(doc, XASafariDocument)
@@ -644,8 +549,6 @@ class XASafariDocument(XASafariGeneric, XAClipboardCodable, XABaseScriptable.XAS
     def __init__(self, properties):
         super().__init__(properties)
 
-        logging.debug("Initialized XASafariDocument")
-
     @property
     def name(self) -> str:
         """The title of the document.
@@ -732,7 +635,6 @@ class XASafariTabList(XABase.XAList, XAClipboardCodable):
     """
     def __init__(self, properties: dict, filter: Union[dict, None] = None):
         super().__init__(properties, XASafariTab, filter)
-        logging.debug("Initialized XASafariTabList")
 
     def source(self) -> list[str]:
         """Gets the source HTML of each tab in the list.
@@ -754,25 +656,11 @@ class XASafariTabList(XABase.XAList, XAClipboardCodable):
         return sources
 
     def url(self) -> list[XABase.XAURL]:
-        """Gets the current URL of each tab in the list.
-
-        :return: A list of web URLs
-        :rtype: list[XABase.XAURL]
-        
-        .. versionadded:: 0.0.4
-        """
-        ls = self.xa_elem.arrayByApplyingSelector_("URL")
+        ls = self.xa_elem.arrayByApplyingSelector_("URL") or []
         return [XABase.XAURL(x) for x in ls]
 
     def index(self) -> list[int]:
-        """Gets the index of each tab in the list.
-
-        :return: A list of indices
-        :rtype: list[int]
-        
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("index"))
+        return list(self.xa_elem.arrayByApplyingSelector_("index") or [])
 
     def text(self) -> list[XABase.XAText]:
         """Gets the visible text of each tab in the list.
@@ -794,87 +682,31 @@ class XASafariTabList(XABase.XAList, XAClipboardCodable):
         return texts
 
     def visible(self) -> list[bool]:
-        """Gets the visible status of each tab in the list.
-
-        :return: A list of visible status booleans
-        :rtype: list[str]
-        
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("visible"))
+        return list(self.xa_elem.arrayByApplyingSelector_("visible") or [])
 
     def name(self) -> list[str]:
-        """Gets the name of each tab in the list.
-
-        :return: A list of tab names
-        :rtype: list[str]
-        
-        .. versionadded:: 0.0.4
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("name"))
+        return list(self.xa_elem.arrayByApplyingSelector_("name") or [])
 
     def by_source(self, source: str) -> Union['XASafariTab', None]:
-        """Retrieves the tab whose source HTML matches the given HTML, if one exists.
-
-        :return: The desired tab, if it is found
-        :rtype: Union[XASafariTab, None]
-        
-        .. versionadded:: 0.0.4
-        """
         for tab in self.xa_elem:
             if tab.source() == source:
                 return self._new_element(tab, XASafariTab)
 
     def by_url(self, url: XABase.XAURL) -> Union['XASafariTab', None]:
-        """Retrieves the tab whose URL matches the given URL, if one exists.
-
-        :return: The desired tab, if it is found
-        :rtype: Union[XASafariTab, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("URL", str(url.xa_elem))
 
     def by_index(self, index: int) -> Union['XASafariTab', None]:
-        """Retrieves the tab whose index matches the given index, if one exists.
-
-        :return: The desired tab, if it is found
-        :rtype: Union[XASafariTab, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("index", index)
 
     def by_text(self, text: Union[str, XABase.XAText]) -> Union['XASafariTab', None]:
-        """Retrieves the tab whose visible text matches the given text, if one exists.
-
-        :return: The desired tab, if it is found
-        :rtype: Union[XASafariTab, None]
-        
-        .. versionadded:: 0.0.4
-        """
         for tab in self.xa_elem:
             if tab.text() == str(text):
                 return self._new_element(tab, XASafariTab)
 
     def by_visible(self, visible: bool) -> Union['XASafariTab', None]:
-        """Retrieves the tab whose visible status matches the given boolean, if one exists.
-
-        :return: The desired tab, if it is found
-        :rtype: Union[XASafariTab, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("visible", visible)
 
     def by_name(self, name: str) -> Union['XASafariTab', None]:
-        """Retrieves the tab whose name matches the given name, if one exists.
-
-        :return: The desired tab, if it is found
-        :rtype: Union[XASafariTab, None]
-        
-        .. versionadded:: 0.0.4
-        """
         return self.by_property("name", name)
 
     def reload(self) -> Self:
@@ -1005,8 +837,6 @@ class XASafariTab(XASafariGeneric, XAClipboardCodable):
     def __init__(self, properties):
         super().__init__(properties)
 
-        logging.debug("Initialized XASafariTab")
-
     @property
     def source(self) -> str:
         """The HTML source of the web page currently loaded in the tab.
