@@ -15,8 +15,6 @@ from ..XAProtocols import XACanOpenPath, XACanPrintPath, XAClipboardCodable, XAC
 class XATextEditApplication(XABaseScriptable.XASBApplication, XACanOpenPath, XACanPrintPath):
     """A class for managing and interacting with TextEdit.app.
 
-    .. seealso:: :class:`XATextEditWindow`, :class:`XATextEditDocument`
-
     .. versionadded:: 0.0.1
     """
 
@@ -214,8 +212,6 @@ class XATextEditApplication(XABaseScriptable.XASBApplication, XACanOpenPath, XAC
 class XATextEditWindow(XABaseScriptable.XASBWindow, XABaseScriptable.XASBPrintable):
     """A class for managing and interacting with TextEdit windows.
 
-    .. seealso:: :class:`XATextEditApplication`
-
     .. versionadded:: 0.0.1
     """
     def __init__(self, properties):
@@ -263,14 +259,7 @@ class XATextEditDocumentList(XABase.XATextDocumentList, XAClipboardCodable):
         super().__init__(properties, filter, XATextEditDocument)
 
     def properties(self) -> list[dict]:
-        """Gets the properties of each document in the list.
-
-        :return: A list of document properties dictionaries
-        :rtype: list[dict]
-        
-        .. versionadded:: 0.0.3
-        """
-        raw_dicts = list(self.xa_elem.arrayByApplyingSelector_("properties"))
+        raw_dicts = list(self.xa_elem.arrayByApplyingSelector_("properties") or [])
         return [{
             "modified": raw_dict["modified"],
             "name": raw_dict["name"],
@@ -280,44 +269,16 @@ class XATextEditDocumentList(XABase.XATextDocumentList, XAClipboardCodable):
         } for raw_dict in raw_dicts]
 
     def path(self) -> list[XABase.XAPath]:
-        """Gets the path of each document in the list.
-
-        :return: A list of document paths
-        :rtype: list[XABase.XAPath]
-        
-        .. versionadded:: 0.0.3
-        """
-        ls = self.xa_elem.arrayByApplyingSelector_("path")
+        ls = self.xa_elem.arrayByApplyingSelector_("path") or []
         return [XABase.XAPath(x) for x in ls]
 
     def name(self) -> list[str]:
-        """Gets the name of each document in the list.
-
-        :return: A list of document names
-        :rtype: list[str]
-        
-        .. versionadded:: 0.0.3
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("name"))
+        return list(self.xa_elem.arrayByApplyingSelector_("name") or [])
 
     def modified(self) -> list[str]:
-        """Gets the modified status of each document in the list.
-
-        :return: A list of modified status booleans
-        :rtype: list[bool]
-        
-        .. versionadded:: 0.0.3
-        """
-        return list(self.xa_elem.arrayByApplyingSelector_("modified"))
+        return list(self.xa_elem.arrayByApplyingSelector_("modified") or [])
 
     def by_properties(self, properties: dict) -> Union['XABase.XATextDocument', None]:
-        """Retrieves the document whose properties match the given properties dictionary, if one exists.
-
-        :return: The desired document, if it is found
-        :rtype: Union[XATextDocument, None]
-        
-        .. versionadded:: 0.1.0
-        """
         for document in self.xa_elem:
             doc_props = document.properties()
             conditions = [
@@ -330,35 +291,14 @@ class XATextEditDocumentList(XABase.XATextDocumentList, XAClipboardCodable):
                 return self._new_element(document, self.xa_ocls)
 
     def by_path(self, path: Union[str, XABase.XAPath]) -> Union['XATextEditDocument', None]:
-        """Retrieves the document whose path matches the given path, if one exists.
-
-        :return: The desired document, if it is found
-        :rtype: Union[XATextEditDocument, None]
-        
-        .. versionadded:: 0.0.3
-        """
         if isinstance(path, XABase.XAPath):
             path = path.path
         return self.by_property("path", path)
 
     def by_name(self, name: str) -> Union['XATextEditDocument', None]:
-        """Retrieves the first document whose name matches the given name, if one exists.
-
-        :return: The desired document, if it is found
-        :rtype: Union[XATextEditDocument, None]
-        
-        .. versionadded:: 0.0.3
-        """
         return self.by_property("name", name)
 
     def by_modified(self, modified: bool) -> Union['XATextEditDocument', None]:
-        """Retrieves the first document whose modified status matches the given boolean value, if one exists.
-
-        :return: The desired document, if it is found
-        :rtype: Union[XATextEditDocument, None]
-        
-        .. versionadded:: 0.0.3
-        """
         return self.by_property("modified", modified)
 
     def prepend(self, text: str) -> 'XATextEditDocumentList':
@@ -481,8 +421,6 @@ class XATextEditDocumentList(XABase.XATextDocumentList, XAClipboardCodable):
 class XATextEditDocument(XABase.XATextDocument, XAPrintable, XAClipboardCodable, XACloseable):
     """A class for managing and interacting with TextEdit documents.
 
-    .. seealso:: :class:`XATextEditApplication`
-
     .. versionchanged:: 0.0.2
 
        Added :func:`close`, :func:`save`, and :func:`copy`
